@@ -1,23 +1,8 @@
 /*
-   This file is part of the KDE libraries
-
-   Copyright (c) 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCMODULE_H
@@ -26,13 +11,12 @@
 #include <kconfigwidgets_export.h>
 
 #ifndef KCONFIGWIDGETS_NO_KAUTH
-#include <kauthaction.h>
+#include <KAuthAction>
 #endif
 
 #include <QVariant>
 #include <QWidget>
 
-class QStringList;
 class KAboutData;
 class KConfigDialogManager;
 class KCoreConfigSkeleton;
@@ -232,6 +216,13 @@ public:
      */
     bool needsAuthorization() const;
 
+    /**
+     * Returns whether an indicator is shown when a setting differs from default.
+     *
+     * @since 5.73
+     */
+    bool defaultsIndicatorsVisible() const;
+
 #ifndef KCONFIGWIDGETS_NO_KAUTH
     /**
      * @brief Set if the module's save() method requires authorization to be executed
@@ -321,6 +312,13 @@ public Q_SLOTS:
      */
     virtual void defaults();
 
+    /**
+     * Show an indicator when settings value differ from default
+     *
+     * @since 5.73
+     */
+    void setDefaultsIndicatorsVisible(bool show);
+
 protected:
     /**
      * Adds a KCoreConfigskeleton @p config to watch the widget @p widget
@@ -396,6 +394,12 @@ Q_SIGNALS:
      */
     void rootOnlyMessageChanged(bool use, QString message);
 
+    /**
+     * Emitted when show defaults indicators changed
+     * @since 5.73
+     */
+    void defaultsIndicatorsVisibleChanged(bool show);
+
 protected Q_SLOTS:
 
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 64)
