@@ -1,26 +1,13 @@
 /*
- *  This file is part of the KDE libraries
- *  Copyright (C) 2003 Benjamin C Meyer (ben+kdelibs at meyerhome dot net)
- *  Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
- *  Copyright (C) 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
- *  Copyright (C) 2020 Kevin Ottens <kevin.ottens@enioka.com>
- *  Copyright (C) 2020 Cyril Rossi <cyril.rossi@enioka.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2003 Benjamin C Meyer <ben+kdelibs at meyerhome dot net>
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2017 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2020 Kevin Ottens <kevin.ottens@enioka.com>
+    SPDX-FileCopyrightText: 2020 Cyril Rossi <cyril.rossi@enioka.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kconfigdialogmanager.h"
 #include "kconfigdialogmanager_p.h"
@@ -582,10 +569,23 @@ bool KConfigDialogManager::hasChanged() const
 
 bool KConfigDialogManager::isDefault() const
 {
-    bool bUseDefaults = d->m_conf->useDefaults(true);
-    bool result = !hasChanged();
-    d->m_conf->useDefaults(bUseDefaults);
-    return result;
+    QWidget *widget;
+    QHashIterator<QString, QWidget *> it(d->knownWidget);
+    while (it.hasNext()) {
+        it.next();
+        widget = it.value();
+
+        KConfigSkeletonItem *item = d->m_conf->findItem(it.key());
+        if (!item) {
+            qCWarning(KCONFIG_WIDGETS_LOG) << "The setting '" << it.key() << "' has disappeared!";
+            continue;
+        }
+
+        if (property(widget) != item->getDefault()) {
+            return false;
+        }
+    }
+    return true;
 }
 
 KConfigDialogManagerPrivate::KConfigDialogManagerPrivate(KConfigDialogManager *q)
@@ -627,12 +627,7 @@ void KConfigDialogManagerPrivate::updateWidgetIndicator(const QString &configId,
     Q_ASSERT(item);
 
     const auto widgetValue = q->property(widget);
-    const auto defaultValue = [item] {
-        item->swapDefault();
-        const auto value = item->property();
-        item->swapDefault();
-        return value;
-    }();
+    const auto defaultValue = item->getDefault();
 
     const auto defaulted = widgetValue == defaultValue;
 
