@@ -26,16 +26,16 @@ CodecActionTest::CodecActionTest(QWidget *parent)
     , m_buttonCodec(new KCodecAction(QStringLiteral("Button Codec Action"), this))
 {
     m_comboCodec->setToolBarMode(KCodecAction::ComboBoxMode);
-    connect(m_comboCodec, SIGNAL(triggered(QAction*)), SLOT(triggered(QAction*)));
-    connect(m_comboCodec, SIGNAL(triggered(int)), SLOT(triggered(int)));
-    connect(m_comboCodec, SIGNAL(triggered(QString)), SLOT(triggered(QString)));
-    connect(m_comboCodec, SIGNAL(triggered(QTextCodec*)), SLOT(triggered(QTextCodec*)));
+    connect(m_comboCodec, SIGNAL(triggered(QAction*)), SLOT(actionTriggered(QAction*)));
+    connect(m_comboCodec, SIGNAL(indexTriggered(int)), SLOT(indexTriggered(int)));
+    connect(m_comboCodec, SIGNAL(textTriggered(QString)), SLOT(textTriggered(QString)));
+    connect(m_comboCodec, SIGNAL(codecTriggered(QTextCodec*)), SLOT(codecTriggered(QTextCodec*)));
 
     m_buttonCodec->setToolBarMode(KCodecAction::MenuMode);
-    connect(m_buttonCodec, SIGNAL(triggered(QAction*)), SLOT(triggered(QAction*)));
-    connect(m_buttonCodec, SIGNAL(triggered(int)), SLOT(triggered(int)));
-    connect(m_buttonCodec, SIGNAL(triggered(QString)), SLOT(triggered(QString)));
-    connect(m_buttonCodec, SIGNAL(triggered(QTextCodec*)), SLOT(triggered(QTextCodec*)));
+    connect(m_buttonCodec, SIGNAL(triggered(QAction*)), SLOT(actionTriggered(QAction*)));
+    connect(m_buttonCodec, SIGNAL(indexTriggered(int)), SLOT(indexTriggered(int)));
+    connect(m_buttonCodec, SIGNAL(textTriggered(QString)), SLOT(textTriggered(QString)));
+    connect(m_buttonCodec, SIGNAL(codecTriggered(QTextCodec*)), SLOT(codecTriggered(QTextCodec*)));
 
     menuBar()->addAction(m_comboCodec);
     menuBar()->addAction(m_buttonCodec);
@@ -45,22 +45,22 @@ CodecActionTest::CodecActionTest(QWidget *parent)
     toolBar->addAction(m_buttonCodec);
 }
 
-void CodecActionTest::triggered(QAction *action)
+void CodecActionTest::actionTriggered(QAction *action)
 {
     qDebug() << action;
 }
 
-void CodecActionTest::triggered(int index)
+void CodecActionTest::indexTriggered(int index)
 {
     qDebug() << index;
 }
 
-void CodecActionTest::triggered(const QString &text)
+void CodecActionTest::textTriggered(const QString &text)
 {
     qDebug() << '"' << text << '"';
 }
 
-void CodecActionTest::triggered(QTextCodec *codec)
+void CodecActionTest::codecTriggered(QTextCodec *codec)
 {
     qDebug() << codec->name() << ':' << codec->mibEnum();
 }
